### ADIOS2 gray-scott-kokkos example

This is a 3D 7-point stencil code to simulate the following [Gray-Scott
reaction diffusion model](https://doi.org/10.1126/science.261.5118.189):

#### Differences from the gray-scott example

It uses Kokkos to run the simulation on GPU.
Please use the installed Gray-Scott example directory but run adios2_simulations_gray-scott-kokkos binary. 
